@@ -1,15 +1,19 @@
-# -*- coding: utf-8 -*-
+from plone.app.linkintegrity import testing
 from plone.app.linkintegrity.handlers import findObject
 from plone.app.linkintegrity.testing import create
-from plone.app.linkintegrity.tests.base import DXBaseTestCase
 from plone.app.testing import logout
 
-import six
+import unittest
 
 
-class FindObjectTests:
+class ReferenceGenerationTestCase(unittest.TestCase):
     """ testing the handlers.findObject function """
 
+    layer = testing.PLONE_APP_LINKINTEGRITY_INTEGRATION_TESTING
+
+    def setUp(self):
+        self.portal = self.layer['portal']
+
     def test_relative_to_portal_root_1(self):
         obj, components = findObject(self.portal.doc1, '/plone/doc2')
         self.assertEqual(obj.absolute_url_path(), '/plone/doc2')
@@ -43,20 +47,8 @@ class FindObjectTests:
         # We logout.  This is to check that findObject also finds objects
         # that are not visible to the current user, like a private page.
         # See https://github.com/plone/plone.app.linkintegrity/issues/79
-        # Note that in the Archetypes tests this is no problem,
-        # but for Dexterity it is.  Likely they use a different workflow.
         logout()
 
         obj, components = findObject(self.portal.doc1, path)
         self.assertEqual(obj.absolute_url_path(), '/plone/target')
         self.assertEqual(components, path)
-
-
-class ReferenceGenerationDXTestCase(DXBaseTestCase, FindObjectTests):
-    """findObject testcase for dx content types"""
-
-if six.PY2:
-    from plone.app.linkintegrity.tests.base import ATBaseTestCase
-
-    class ReferenceGenerationATTestCase(ATBaseTestCase, FindObjectTests):
-        """findObject testcase for at content types"""
